summaryrefslogtreecommitdiffstats
path: root/kapptemplate/kpartplugin/plugin_app.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit22253cd8fbc0bd2e70f32aaf1f95ea3a3e819a60 (patch)
treebabc4a761925023e16fa94633959f35d1c251887 /kapptemplate/kpartplugin/plugin_app.cpp
parent0813b39aed2cf4c84157a22c4c9594336d93d412 (diff)
downloadtdesdk-22253cd8fbc0bd2e70f32aaf1f95ea3a3e819a60.tar.gz
tdesdk-22253cd8fbc0bd2e70f32aaf1f95ea3a3e819a60.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdesdk@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kapptemplate/kpartplugin/plugin_app.cpp')
-rw-r--r--kapptemplate/kpartplugin/plugin_app.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/kapptemplate/kpartplugin/plugin_app.cpp b/kapptemplate/kpartplugin/plugin_app.cpp
index c6a27fb8..0ec7a273 100644
--- a/kapptemplate/kpartplugin/plugin_app.cpp
+++ b/kapptemplate/kpartplugin/plugin_app.cpp
@@ -13,9 +13,9 @@ typedef KGenericFactory<Plugin${APP_NAME}> ${APP_NAME}Factory;
K_EXPORT_COMPONENT_FACTORY( lib${APP_NAME_LC}plugin,
${APP_NAME}Factory( "${APP_NAME_LC}" ) );
-Plugin${APP_NAME}::Plugin${APP_NAME}( TQObject* tqparent, const char* name,
+Plugin${APP_NAME}::Plugin${APP_NAME}( TQObject* parent, const char* name,
const TQStringList & /*args*/ )
- : Plugin( tqparent, name )
+ : Plugin( parent, name )
{
// Instantiate all of your actions here. These will appear in
// Konqueror's menu and toolbars.
@@ -33,7 +33,7 @@ void Plugin${APP_NAME}::slotAction()
// This plugin assumes KHTMLPart. If your plugin can handle more
// than this or a different Part than this, simply delete or
// change the following block.
- if ( !tqparent()->inherits("KHTMLPart") )
+ if ( !parent()->inherits("KHTMLPart") )
{
TQString title( i18n( "Cannot Translate Source" ) );
TQString text( i18n( "You cannot translate anything except web pages "
@@ -43,9 +43,9 @@ void Plugin${APP_NAME}::slotAction()
return;
}
// Get a handle on our tqparent so we may get the necessary data for
// processing
- KHTMLPart *part = dynamic_cast<KHTMLPart *>(tqparent());
+ KHTMLPart *part = dynamic_cast<KHTMLPart *>(parent());
// This plugin only uses the URL. You may use whatever data you
// need.
@@ -43,9 +43,9 @@ void Plugin${APP_NAME}::slotAction()
return;
}
- // Get a handle on our tqparent so we may get the necessary data for
+ // Get a handle on our parent so we may get the necessary data for
// processing